@@ -1,24 +1,28 @@
 /*
- * $Id: di.h,v 1.57 2011-10-03 20:14:37-07 bll Exp $
+ * $Id: di.h,v 1.66 2013-01-18 08:32:14-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/di.h,v $
- * Copyright 1994-2011 Brad Lanam, Walnut Creek, CA
+ * Copyright 1994-2013 Brad Lanam, Walnut Creek, CA
  */
 
-#ifndef __INC_DI_H_
-#define __INC_DI_H_
+#ifndef _INC_DI_H
+#define _INC_DI_H
 
 #include "config.h"
 
 /*****************************************************/
 
 #include <stdio.h>
-#if _hdr_fcntl
+#if _hdr_fcntl \
+    && ! defined (_DI_INC_FCNTL_H)  /* xenix */
+# define _DI_INC_FCNTL_H
 # include <fcntl.h>
 #endif
 #if _sys_file
 # include <sys/file.h>
 #endif
-#if _sys_types
+#if _sys_types \
+    && ! defined (_DI_INC_SYS_TYPES_H) /* xenix */
+# define _DI_INC_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 #if _hdr_limits
@@ -27,6 +31,9 @@
 #if _sys_param
 # include <sys/param.h>     /* MAXPATHLEN */
 #endif
+#if _hdr_zone
+# include <zone.h>
+#endif
 
 #if ! defined (O_NOCTTY)
 # define O_NOCTTY 0
@@ -55,8 +62,8 @@
 #  define DI_TYPE_LEN       FSTYPSZ
 # endif
 #endif
-#if _sys_mount && \
-    ! defined (_DI_INC_SYS_MOUNT)       /* NetBSD */
+#if _sys_mount \
+    && ! defined (_DI_INC_SYS_MOUNT)       /* NetBSD */
 # define _DI_INC_SYS_MOUNT 1
 # include <sys/mount.h>                 /* MFSNAMELEN */
 # if ! defined (DI_TYPE_LEN) && defined (MFSNAMELEN)
@@ -74,17 +81,17 @@
 # define DI_TYPE_LEN        65
 #endif
 
-#if ! _lib_memcpy && ! defined (memcpy)
-# if ! _lib_bcopy
-   error No_memcpy/bcopy_available.
+#if ! _lib_memcpy && ! _define_memcpy
+# if ! _lib_bcopy && ! _define_bcopy
+   #error No_memcpy/bcopy_available.
 # else
 #  define memcpy(dst, src, cnt)     (bcopy((src), (dst), (cnt)), dst)
 # endif
 #endif
 
-#if ! _lib_memset && ! defined (memset)
-# if ! _lib_bzero
-   error No_memset/bzero_available.
+#if ! _lib_memset && ! _define_memset
+# if ! _lib_bzero && ! _define_bzero
+   #error No_memset/bzero_available.
 # else
 #  define memset(s,c,n)    (bzero ((s), (n)), s)
 # endif
@@ -137,27 +144,26 @@ typedef unsigned long __ulong;
 typedef struct
 {
     unsigned int    sortIndex [2];
-    _fs_size_t      totalBlocks;
-    _fs_size_t      freeBlocks;
-    _fs_size_t      availBlocks;
-    _fs_size_t      blockSize;
+    _fs_size_t      totalSpace;
+    _fs_size_t      freeSpace;
+    _fs_size_t      availSpace;
     _fs_size_t      totalInodes;
     _fs_size_t      freeInodes;
     _fs_size_t      availInodes;
-    __ulong         st_dev;                      /* disk device number   */
-    __ulong         sp_dev;                      /* special device number*/
-    __ulong         sp_rdev;                     /* special rdev #       */
-    char            doPrint;                     /* do we want to print  */
-                                                 /* this entry?          */
-    char            printFlag;                   /* print flags          */
-    char            isLocal;                     /* is this mount point  */
-                                                 /* local?               */
-    char            isReadOnly;                  /* is this mount point  */
-                                                 /* read-only?           */
-    char            isLoopback;                  /* lofs or none fs type? */
-    char            name [DI_NAME_LEN + 1];         /* mount point          */
-    char            special [DI_SPEC_NAME_LEN + 1]; /* special device name  */
-    char            fsType [DI_TYPE_LEN + 1];       /* type of file system  */
+    __ulong         st_dev;                      /* disk device number       */
+    __ulong         sp_dev;                      /* special device number    */
+    __ulong         sp_rdev;                     /* special rdev #           */
+    char            doPrint;                     /* do we want to print      */
+                                                 /* this entry?              */
+    char            printFlag;                   /* print flags              */
+    char            isLocal;                     /* is this mount point      */
+                                                 /* local?                   */
+    char            isReadOnly;                  /* is this mount point      */
+                                                 /* read-only?               */
+    char            isLoopback;                  /* lofs or none fs type?    */
+    char            name [DI_NAME_LEN + 1];         /* mount point           */
+    char            special [DI_SPEC_NAME_LEN + 1]; /* special device name   */
+    char            fsType [DI_TYPE_LEN + 1];       /* type of file system   */
     char            options [DI_OPT_LEN + 1];
     char            mountTime [DI_MNT_TIME_LEN + 1];
 } diDiskInfo_t;
@@ -176,6 +182,86 @@ typedef struct
     _fs_size_t      iused;
 } diQuota_t;
 
+typedef struct
+{
+    int    count;
+    char   **list;
+} iList_t;
+
+#if ! _lib_zone_list
+# define zoneid_t       int
+# define ZONENAME_MAX   65
+#endif
+
+typedef struct {
+    zoneid_t    zoneid;
+    char        name [ZONENAME_MAX + 1];
+    char        rootpath [MAXPATHLEN + 1];
+    Size_t      rootpathlen;
+} zoneSummary_t;
+
+typedef struct {
+    Uid_t           uid;
+    zoneid_t        myzoneid;
+    zoneSummary_t   *zones;
+    Uint_t          zoneCount;
+    char            zoneDisplay [MAXPATHLEN + 1];
+    int             globalIdx;
+} zoneInfo_t;
+
+#define DI_SORT_MAX             10
+
+typedef struct {
+    const char      *formatString;
+    _print_size_t   dispBlockSize;
+    _print_size_t   baseDispSize;
+    unsigned int    baseDispIdx;
+    char            sortType [DI_SORT_MAX + 1];
+    unsigned int    posix_compat;
+    unsigned int    quota_check;
+    unsigned int    csv_output;
+    unsigned int    excludeLoopback;
+    unsigned int    printTotals;
+    unsigned int    printDebugHeader;
+    unsigned int    printHeader;
+    unsigned int    displayAll;
+    unsigned int    localOnly;
+    unsigned int    dontResolveSymlink;
+} diOptions_t;
+
+typedef struct {
+    Size_t       inodeWidth;
+    Size_t       maxMntTimeString;
+    Size_t       maxMountString;
+    Size_t       maxOptString;
+    Size_t       maxSpecialString;
+    Size_t       maxTypeString;
+    Size_t       width;
+    char         *dispBlockLabel;
+    char         blockFormat [15];
+    char         blockFormatNR [15];   /* no radix */
+    char         inodeFormat [15];
+    char         inodeLabelFormat [15];
+    char         mountFormat [10];
+    char         mTimeFormat [15];
+    char         optFormat [15];
+    char         specialFormat [15];
+    char         typeFormat [10];
+} diOutput_t;
+
+typedef struct {
+    int             count;
+    int             haspooledfs;
+    int             disppooledfs;
+    int             totsorted;
+    diOptions_t     options;
+    diOutput_t      output;
+    diDiskInfo_t    *diskInfo;
+    iList_t         ignoreList;
+    iList_t         includeList;
+    zoneInfo_t      zoneInfo;
+} diData_t;
+
 # if defined (__cplusplus) || defined (c_plusplus)
    extern "C" {
 # endif
@@ -184,11 +270,6 @@ typedef struct
   extern int errno;
 #endif
 
-/* workaround for AIX - mntctl not declared */
-# if _lib_mntctl && _npt_mntctl
-  extern int mntctl _((int, int, char *));
-# endif
-
  /* digetentries.c */
 extern int  di_getDiskEntries       _((diDiskInfo_t **, int *));
  /* digetinfo.c */
@@ -211,17 +292,20 @@ extern _pvoid _realloc               _((_pvoid, Size_t));
 extern void di_initDiskInfo _((diDiskInfo_t *));
 extern void di_saveBlockSizes _((diDiskInfo_t *, _fs_size_t, _fs_size_t, _fs_size_t, _fs_size_t));
 extern void di_saveInodeSizes _((diDiskInfo_t *, _fs_size_t, _fs_size_t, _fs_size_t));
-#if _lib_getmntent && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_mntctl && \
-    ! _class_os__Volumes
+#if _lib_getmntent \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_mntctl \
+    && ! _class_os__Volumes
 extern char *chkMountOptions        _((const char *, const char *));
 #endif
-extern void convertMountOptions     _((long, diDiskInfo_t *));
+extern void convertMountOptions     _((unsigned long, diDiskInfo_t *));
 extern void convertNFSMountOptions  _((long, long, long, diDiskInfo_t *));
 extern void di_testRemoteDisk       _((diDiskInfo_t *));
+extern int  di_isPooledFs           _((diDiskInfo_t *));
+extern int  di_isLoopbackFs         _((diDiskInfo_t *));
+extern Size_t di_mungePoolName      _((char *));
 
 # if defined (__cplusplus) || defined (c_plusplus)
    }
@@ -283,4 +367,4 @@ typedef struct {
 
 # endif
 
-#endif /* __INC_DI_H_ */
+#endif /* _INC_DI_H */
