@@ -1,5 +1,5 @@
 /*
- * $Id: didiskutil.c,v 1.13 2011-09-26 17:49:48-07 bll Exp $
+ * $Id: didiskutil.c,v 1.18 2013-01-18 08:32:21-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/didiskutil.c,v $
  * Copyright 1994-2011 Brad Lanam, Walnut Creek, CA
  */
@@ -83,10 +83,9 @@ di_saveBlockSizes (diptr, block_size, total_blocks, free_blocks, avail_blocks)
     _fs_size_t avail_blocks;
 #endif
 {
-    diptr->blockSize = (_fs_size_t) block_size;
-    diptr->totalBlocks = (_fs_size_t) total_blocks;
-    diptr->freeBlocks = (_fs_size_t) free_blocks;
-    diptr->availBlocks = (_fs_size_t) avail_blocks;
+    diptr->totalSpace = (_fs_size_t) total_blocks * (_fs_size_t) block_size;
+    diptr->freeSpace = (_fs_size_t) free_blocks * (_fs_size_t) block_size;
+    diptr->availSpace = (_fs_size_t) avail_blocks * (_fs_size_t) block_size;
 }
 
 void
@@ -109,10 +108,10 @@ di_saveInodeSizes (diptr, total_nodes, free_nodes, avail_nodes)
 
 void
 #if _proto_stdc
-convertMountOptions (long flags, diDiskInfo_t *diptr)
+convertMountOptions (unsigned long flags, diDiskInfo_t *diptr)
 #else
 convertMountOptions (flags, diptr)
-    long          flags;
+    unsigned long  flags;
     diDiskInfo_t   *diptr;
 #endif
 {
@@ -412,21 +411,21 @@ convertNFSMountOptions (flags, wsize, rsize, diptr)
 }
 
 
-#if _lib_getmntent && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-	! _lib_mntctl && \
-	! _class_os__Volumes
+#if _lib_getmntent \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+	&& ! _lib_mntctl \
+	&& ! _class_os__Volumes
 
 char *
-# if _proto_stdc
+#if _proto_stdc
 chkMountOptions (const char *mntopts, const char *str)
-# else
+#else
 chkMountOptions (mntopts, str)
     const char          *mntopts;
     const char          *str;
-# endif
+#endif
 {
     char    *ptr;
     char    *tstr;
@@ -454,17 +453,78 @@ chkMountOptions (mntopts, str)
 #endif /* _lib_getmntent */
 
 void
-# if _proto_stdc
+#if _proto_stdc
 di_testRemoteDisk (diDiskInfo_t *diskInfo)
-# else
+#else
 di_testRemoteDisk (diskInfo)
     diDiskInfo_t *diskInfo;
-# endif
+#endif
 {
-    if (strcmp (diskInfo->fsType, "nfs") == 0 ||
-            strcmp (diskInfo->fsType, "nfs3") == 0)
-    {
-        diskInfo->isLocal = FALSE;
+  if (strcmp (diskInfo->fsType, "nfs") == 0 ||
+     strcmp (diskInfo->fsType, "nfs3") == 0)
+  {
+    diskInfo->isLocal = FALSE;
+  }
+}
+
+int
+#if _proto_stdc
+di_isPooledFs (diDiskInfo_t *diskInfo)
+#else
+di_isPooledFs (diskInfo)
+    diDiskInfo_t *diskInfo;
+#endif
+{
+  if (strcmp (diskInfo->fsType, "zfs") == 0 ||
+      strcmp (diskInfo->fsType, "advfs") == 0 ||
+      (strcmp (diskInfo->fsType, "null") == 0 &&
+       strstr (diskInfo->special, "/@@-") != (char *) NULL)) {
+    return TRUE;
+  }
+  return FALSE;
+}
+
+int
+#if _proto_stdc
+di_isLoopbackFs (diDiskInfo_t *diskInfo)
+#else
+di_isLoopbackFs (diskInfo)
+    diDiskInfo_t *diskInfo;
+#endif
+{
+  if ((strcmp (diskInfo->fsType, "lofs") == 0 && diskInfo->sp_rdev != 0) ||
+      (strcmp (diskInfo->fsType, "null") == 0 &&
+       strstr (diskInfo->special, "/@@-") == (char *) NULL) ||
+      strcmp (diskInfo->fsType, "none") == 0) {
+    return TRUE;
+  }
+  return FALSE;
+}
+
+Size_t
+#if _proto_stdc
+di_mungePoolName (char *poolname)
+#else
+di_mungePoolName (poolname)
+  char      *poolname;
+#endif
+{
+  char      *ptr;
+
+  ptr = strchr (poolname, '#');   /* advfs */
+  if (ptr != (char *) NULL) {
+    *ptr = '\0';
+  } else {
+    ptr = strchr (poolname, ':');   /* dragonflybsd */
+    if (ptr != (char *) NULL) {
+      *ptr = '\0';
+    } else {
+      ptr = strchr (poolname, '/');   /* zfs */
+      if (ptr != (char *) NULL) {
+        *ptr = '\0';
+      }
     }
+  }
+  return strlen (poolname);
 }
 
