@@ -1,5 +1,5 @@
 /*
- * $Id: digetentries.c,v 1.36 2011-10-04 16:52:07-07 bll Exp $
+ * $Id: digetentries.c,v 1.44 2013-01-18 08:32:35-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/digetentries.c,v $
  * Copyright 1994-2011 Brad Lanam, Walnut Creek, CA
  */
@@ -27,7 +27,9 @@
 #if _hdr_dirent
 # include <dirent.h>
 #endif
-#if _sys_types
+#if _sys_types \
+    && ! defined (_DI_INC_SYS_TYPES_H) /* xenix */
+# define _DI_INC_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 #if _sys_param
@@ -57,22 +59,15 @@
 #if _hdr_malloc
 # include <malloc.h>
 #endif
-#if _hdr_time
-# include <time.h>
-#endif
-#if _sys_time && _inc_conflict__hdr_time__sys_time
-# include <sys/time.h>
-#endif
 
-
-#if _hdr_mntent && \
-  ! defined (_DI_INC_MNTENT)        /* Linux, kFreeBSD, HP-UX */
+#if _hdr_mntent \
+  && ! defined (_DI_INC_MNTENT)        /* Linux, kFreeBSD, HP-UX */
 # define _DI_INC_MNTENT 1
 # include <mntent.h>            /* hasmntopt(); _PATH_MNTTAB */
 #endif                          /* HP-UX: set/get/endmntent(); hasmntopt() */
 
-#if _sys_mount && \
-  ! defined (_DI_INC_SYS_MOUNT) /* FreeBSD, OpenBSD, NetBSD, HP-UX */
+#if _sys_mount \
+  && ! defined (_DI_INC_SYS_MOUNT) /* FreeBSD, OpenBSD, NetBSD, HP-UX */
 # define _DI_INC_SYS_MOUNT 1
 # include <sys/mount.h>         /* getmntinfo(); struct statfs */
 #endif
@@ -158,14 +153,19 @@
   extern "C" {
 #endif
 
-#if (_lib_getmntent || \
-    _args_statfs > 0) && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_mntctl && \
-    ! _lib_getmnt && \
-    ! _class_os__Volumes
+/* workaround for AIX - mntctl not declared */
+# if _lib_mntctl && _npt_mntctl
+  extern int mntctl _((int, Size_t, char *));
+# endif
+
+#if (_lib_getmntent \
+    || _args_statfs > 0) \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_mntctl \
+    && ! _lib_getmnt \
+    && ! _class_os__Volumes
 # if defined (_PATH_MOUNTED)
 #  define DI_MOUNT_FILE        _PATH_MOUNTED
 # else
@@ -200,10 +200,10 @@ extern int debug;
 
 /********************************************************/
 
-#if _lib_getmntent && \
-    ! _lib_setmntent && \
-    ! _lib_mntctl && \
-    ! _class_os__Volumes
+#if _lib_getmntent \
+    && ! _lib_setmntent \
+    && ! _lib_mntctl \
+    && ! _class_os__Volumes
 
 #if defined (__cplusplus) || defined (c_plusplus)
   extern "C" {
@@ -233,7 +233,6 @@ di_getDiskEntries (diskInfo, diCount)
     FILE            *f;
     int             idx;
     struct mnttab   mntEntry;
-    time_t          mtime;
     char            *devp;   /* local ptr to dev entry */
 
 
@@ -278,8 +277,6 @@ di_getDiskEntries (diskInfo, diCount)
             diptr->isReadOnly = TRUE;
         }
         strncpy (diptr->options, mntEntry.mnt_mntopts, DI_OPT_LEN);
-        mtime = atol (mntEntry.mnt_time);
-        strncpy (diptr->mountTime, ctime (&mtime), DI_MNT_TIME_LEN);
 
             /* get the file system type now... */
         strncpy (diptr->fsType, mntEntry.mnt_fstype, DI_TYPE_LEN);
@@ -316,16 +313,16 @@ checkMountOptions (mntEntry, str)
 
 #endif
 
-#if _lib_getmntent && \
-    _lib_setmntent && \
-    _lib_endmntent && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_mntctl && \
-    ! _lib_GetDriveType && \
-    ! _lib_GetLogicalDriveStrings && \
-    ! _class_os__Volumes
+#if _lib_getmntent \
+    && _lib_setmntent \
+    && _lib_endmntent \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_mntctl \
+    && ! _lib_GetDriveType \
+    && ! _lib_GetLogicalDriveStrings \
+    && ! _class_os__Volumes
 
 /*
  * di_getDiskEntries
@@ -425,18 +422,18 @@ di_getDiskEntries (diskInfo, diCount)
 #endif /* _lib_getmntent && _lib_setmntent && _lib_endmntent */
 
 /* QNX */
-#if ! _lib_getmntent && \
-    ! _lib_mntctl && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_getmnt && \
-    ! _lib_GetDriveType && \
-    ! _lib_GetLogicalDriveStrings && \
-    ! _lib_fs_stat_dev && \
-    ! _class_os__Volumes && \
-    ! _lib_sys_dollar_device_scan && \
-    defined (__QNX__)
+#if ! _lib_getmntent \
+    && ! _lib_mntctl \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_getmnt \
+    && ! _lib_GetDriveType \
+    && ! _lib_GetLogicalDriveStrings \
+    && ! _lib_fs_stat_dev \
+    && ! _class_os__Volumes \
+    && ! _lib_sys_dollar_device_scan \
+    && defined (__QNX__)
 
 /*
  * di_getDiskEntries
@@ -574,18 +571,18 @@ di_getQNXDiskEntries (ipath, diskInfo, diCount)
 #endif /* QNX */
 
 /* if nothing matches, assume a SysV.3 /etc/mnttab or similar */
-#if ! _lib_getmntent && \
-    ! _lib_mntctl && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_getmnt && \
-    ! _lib_GetDriveType && \
-    ! _lib_GetLogicalDriveStrings && \
-    ! _lib_fs_stat_dev && \
-    ! _class_os__Volumes && \
-    ! _lib_sys_dollar_device_scan && \
-    ! defined (__QNX__)
+#if ! _lib_getmntent \
+    && ! _lib_mntctl \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_getmnt \
+    && ! _lib_GetDriveType \
+    && ! _lib_GetLogicalDriveStrings \
+    && ! _lib_fs_stat_dev \
+    && ! _class_os__Volumes \
+    && ! _lib_sys_dollar_device_scan \
+    && ! defined (__QNX__)
 
 /*
  * di_getDiskEntries
@@ -603,6 +600,7 @@ di_getDiskEntries (diskInfo, diCount)
     int *diCount;
 # endif
 {
+    diDiskInfo_t    *diptr;
     FILE             *f;
     int              idx;
     struct mnttab    mntEntry;
@@ -626,6 +624,7 @@ di_getDiskEntries (diskInfo, diCount)
             ++*diCount;
             *diskInfo = (diDiskInfo_t *) _realloc ((char *) *diskInfo,
                     sizeof (diDiskInfo_t) * *diCount);
+            diptr = *diskInfo + idx;
             di_initDiskInfo (diptr);
 
 # if defined (COHERENT)
@@ -636,9 +635,9 @@ di_getDiskEntries (diskInfo, diCount)
             strncpy (diptr->special, mntEntry.mt_dev, DI_SPEC_NAME_LEN);
             strncpy (diptr->name, mntEntry.mt_filsys, DI_NAME_LEN);
 # endif
-            strncpy (diptr->options, mntEntry.mnt_mntopts, DI_OPT_LEN);
-            strncpy (diptr->mountTime, mntEntry.mnt_time,
-                    DI_MNT_TIME_LEN);
+# if _mem_struct_mnttab_mntopts
+            strncpy (diptr->options, mntEntry.mt_mntopts, DI_OPT_LEN);
+# endif
         }
 
         if (debug > 1)
@@ -659,8 +658,8 @@ di_getDiskEntries (diskInfo, diCount)
  */
 
 
-#if _lib_getfsstat && \
-    ! (_lib_getvfsstat && _args_getvfsstat == 3)
+#if _lib_getfsstat \
+    && ! (_lib_getvfsstat && _args_getvfsstat == 3)
 
 /*
  * di_getDiskEntries
@@ -737,7 +736,7 @@ di_getDiskEntries (diskInfo, diCount)
             diptr->isLocal = FALSE;
         }
 # endif
-        convertMountOptions ((long) sp->f_flags, diptr);
+        convertMountOptions ((unsigned long) sp->f_flags, diptr);
 # if _mem_struct_statfs_f_type
 #  if defined (MOUNT_NFS3)
         if (sp->f_type == MOUNT_NFS3)
@@ -747,9 +746,9 @@ di_getDiskEntries (diskInfo, diCount)
         }
 #  endif
 # endif
-# if _mem_struct_statfs_mount_info && \
-        defined (MOUNT_NFS) && \
-        (_mem_struct_statfs_f_type || _mem_struct_statfs_f_fstypename)
+# if _mem_struct_statfs_mount_info \
+        && defined (MOUNT_NFS) \
+        && (_mem_struct_statfs_f_type || _mem_struct_statfs_f_fstypename)
 #  if _mem_struct_statfs_f_type
         if (sp->f_type == MOUNT_NFS
 #  endif
@@ -815,9 +814,9 @@ di_getDiskEntries (diskInfo, diCount)
 
 #endif /* _lib_getfsstat */
 
-#if _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat
+#if _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat
 
 # define DI_UNKNOWN_FSTYPE       "(%.2d)?"
 
@@ -910,8 +909,8 @@ di_getDiskEntries (diskInfo, diCount)
             (_fs_size_t) mntbufp [idx].f_ffree);
 
         fstype = mntbufp [idx].f_type;
-# if ! _sys_fs_types && ! defined (INITMOUNTNAMES) && \
-    ! _mem_struct_statfs_f_fstypename
+# if ! _sys_fs_types && ! defined (INITMOUNTNAMES) \
+    && ! _mem_struct_statfs_f_fstypename
         if ((fstype >= 0) && (fstype <= MOUNT_MAXTYPE))
         {
             switch (fstype)
@@ -1068,7 +1067,7 @@ di_getDiskEntries (diskInfo, diCount)
             diptr->isReadOnly = TRUE;
         }
 # endif
-        convertMountOptions ((long) mntbufp [idx].f_flags, diptr);
+        convertMountOptions ((unsigned long) mntbufp [idx].f_flags, diptr);
         trimChar (diptr->options, ',');
 
         if (debug > 1)
@@ -1132,7 +1131,7 @@ di_getDiskEntries (diskInfo, diCount)
         fprintf (stderr, "Unable to do getvfsstat () errno %d\n", errno);
         return -1;
     }
-    bufsize = sizeof (struct statvfs) * count;
+    bufsize = sizeof (struct statvfs) * (Size_t) count;
     mntbufp = malloc ((Size_t) bufsize);
     memset ((char *) mntbufp, '\0', sizeof (struct statvfs) * (Size_t) count);
     count = getvfsstat (mntbufp, (Size_t) bufsize, ST_NOWAIT);
@@ -1144,7 +1143,7 @@ di_getDiskEntries (diskInfo, diCount)
         fprintf (stderr, "malloc failed for diskInfo. errno %d\n", errno);
         return -1;
     }
-    memset ((char *) *diskInfo, '\0', sizeof (diDiskInfo_t) * count);
+    memset ((char *) *diskInfo, '\0', sizeof (diDiskInfo_t) * (Size_t) count);
 
     for (idx = 0; idx < count; idx++)
     {
@@ -1167,7 +1166,7 @@ di_getDiskEntries (diskInfo, diCount)
             diptr->isLocal = FALSE;
         }
 # endif
-        convertMountOptions ((long) sp->f_flag, diptr);
+        convertMountOptions ((unsigned long) sp->f_flag, diptr);
         trimChar (diptr->options, ',');
 
         if (sp->f_frsize == 0 && sp->f_bsize != 0)
@@ -1334,7 +1333,7 @@ di_getDiskEntries (diskInfo, diCount)
         {
             diptr->isReadOnly = FALSE;
         }
-        convertMountOptions ((long) fsdbuf [idx].fd_req.flags, diptr);
+        convertMountOptions ((unsigned long) fsdbuf [idx].fd_req.flags, diptr);
         trimChar (diptr->options, ',');
 
         if (debug > 1)
@@ -1416,7 +1415,7 @@ di_getDiskEntries (diskInfo, diCount)
             return -1;
         }
 
-        num = mntctl (MCTL_QUERY, (int) vmbufsz, vmbuf);
+        num = mntctl (MCTL_QUERY, vmbufsz, vmbuf);
             /*
              * vmbuf is too small, could happen for
              * following reasons:
@@ -1445,7 +1444,7 @@ di_getDiskEntries (diskInfo, diCount)
     if (num == -1)
     {
         free ((char *) vmbuf);
-        fprintf (stderr,"%s errno %d\n", strerror (errno), errno);
+        fprintf (stderr, "%s errno %d\n", strerror (errno), errno);
         return -1;
     }
 
@@ -1509,9 +1508,6 @@ di_getDiskEntries (diskInfo, diCount)
         strncpy (diptr->options, (char *) vmt2dataptr (vmtp, VMT_ARGS),
                  DI_OPT_LEN);
         trimChar (diptr->options, ',');
-
-        strncpy (diptr->mountTime, ctime ((time_t *) &vmtp->vmt_time),
-                DI_MNT_TIME_LEN);
         bufp += vmtp->vmt_length;
 
         if (debug > 1)
@@ -1527,8 +1523,8 @@ di_getDiskEntries (diskInfo, diCount)
 #endif  /* _lib_mntctl */
 
 
-#if _lib_GetDriveType && \
-    _lib_GetLogicalDriveStrings
+#if _lib_GetDriveType \
+    && _lib_GetLogicalDriveStrings
 
 /*
  * di_getDiskInfo
@@ -1624,8 +1620,8 @@ di_getDiskEntries (diskInfo, diCount)
 
 #endif  /* _lib_GetDiskFreeSpace || _lib_GetDiskFreeSpaceEx */
 
-#if _lib_fs_stat_dev && \
-    _lib_next_dev
+#if _lib_fs_stat_dev \
+    && _lib_next_dev
 
 /*
  * di_getDiskEntries
@@ -1699,7 +1695,7 @@ di_getDiskEntries (diskInfo, diCount)
            diptr->printFlag = DI_PRNT_IGNORE;
         }
 # endif
-        convertMountOptions ((long) fsinfo.flags, diptr);
+        convertMountOptions ((unsigned long) fsinfo.flags, diptr);
         trimChar (diptr->options, ',');
 
         if (debug > 1)
@@ -1787,7 +1783,7 @@ di_getDiskEntries (diskInfo, diCount)
            diptr->printFlag = DI_PRNT_IGNORE;
         }
 # endif
-        convertMountOptions ((long) fsinfo.fi_flags, diptr);
+        convertMountOptions ((unsigned long) fsinfo.fi_flags, diptr);
         trimChar (diptr->options, ',');
 
         if (debug > 1)
@@ -2165,8 +2161,7 @@ di_getDiskEntries (diskInfo, diCount)
       ;
     }
 
-    di_saveBlockSizes (diptr, tblocksz,
-          totBlocks, freeBlocks, freeBlocks);
+    di_saveBlockSizes (diptr, tblocksz, totBlocks, freeBlocks, freeBlocks);
     di_saveInodeSizes (diptr, maxFiles, 0, 0);
 
     /* reset this so there's room during the next syscall */
