@@ -1,5 +1,5 @@
 /*
- * $Id: digetinfo.c,v 1.20 2011-09-26 17:49:51-07 bll Exp $
+ * $Id: digetinfo.c,v 1.23 2013-01-18 14:12:59-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/digetinfo.c,v $
  * Copyright 1994-2011 Brad Lanam, Walnut Creek, CA
  */
@@ -28,7 +28,9 @@
 #if _hdr_stdlib
 # include <stdlib.h>
 #endif
-#if _sys_types
+#if _sys_types \
+    && ! defined (_DI_INC_SYS_TYPES_H) /* xenix */
+# define _DI_INC_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 #if _sys_param
@@ -44,8 +46,8 @@
 # include <strings.h>
 #endif
 
-#if _sys_mount && \
-  ! defined (_DI_INC_SYS_MOUNT) /* FreeBSD, OpenBSD, NetBSD, HP-UX */
+#if _sys_mount \
+  && ! defined (_DI_INC_SYS_MOUNT) /* FreeBSD, OpenBSD, NetBSD, HP-UX */
 # define _DI_INC_SYS_MOUNT 1
 # include <sys/mount.h>         /* statfs(); struct statfs; getfsstat() */
 #endif
@@ -71,9 +73,9 @@
   extern "C" {
 #endif
 
-#if ! _lib_statvfs && \
-	_lib_statfs && \
-	_npt_statfs
+#if ! _lib_statvfs \
+	&& _lib_statfs \
+	&& _npt_statfs
 # if _lib_statfs && _args_statfs == 2
   extern int statfs _((char *, struct statfs *));
 # endif
@@ -93,13 +95,13 @@ extern int debug;
 
 /********************************************************/
 
-#if _lib_statvfs && \
-    ! _lib_fs_stat_dev && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_GetVolumeInformation && \
-	! _class_os__Volumes
+#if _lib_statvfs \
+    && ! _lib_fs_stat_dev \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_GetVolumeInformation \
+	&& ! _class_os__Volumes
 
 /*
  * di_getDiskInfo
@@ -191,8 +193,11 @@ di_getDiskInfo (diskInfo, diCount)
             }
             else
             {
+              diptr->printFlag = DI_PRNT_BAD;
+              if (errno != EACCES) {
                 fprintf (stderr, "statvfs: %s ", diptr->name);
                 perror ("");
+              }
             }
         }
     } /* for each entry */
@@ -200,18 +205,24 @@ di_getDiskInfo (diskInfo, diCount)
 
 #endif /* _lib_statvfs */
 
-#if _lib_statfs && _args_statfs == 4 && \
-    ! _lib_statvfs && \
-    ! _lib_getmntinfo && \
-    ! _lib_getfsstat && \
-    ! _lib_getvfsstat && \
-    ! _lib_getmnt
+#if _lib_statfs && _args_statfs == 4 \
+    && ! _lib_statvfs \
+    && ! _lib_getmntinfo \
+    && ! _lib_getfsstat \
+    && ! _lib_getvfsstat \
+    && ! _lib_getmnt
 
-# if ! defined (UBSIZE)
-#  if defined (BSIZE)
-#   define UBSIZE            BSIZE
-#  else
-#   define UBSIZE            512
+  /* xenix reports a block size of 1024 bytes, but the blocks reported */
+  /* are based on a 512 byte block size.                               */
+# if defined (M_XENIX)
+#  define UBSIZE            512
+# else
+#  if ! defined (UBSIZE)
+#   if defined (BSIZE)
+#    define UBSIZE            BSIZE
+#   else
+#    define UBSIZE            512
+#   endif
 #  endif
 # endif
 
@@ -291,8 +302,11 @@ di_getDiskInfo (diskInfo, diCount)
             } /* if we got the info */
             else
             {
+              diptr->printFlag = DI_PRNT_BAD;
+              if (errno != EACCES) {
                 fprintf (stderr, "statfs: %s ", diptr->name);
                 perror ("");
+              }
             }
         }
     } /* for each entry */
@@ -300,13 +314,13 @@ di_getDiskInfo (diskInfo, diCount)
 
 #endif /* _args_statfs == 4 */
 
-#if _lib_statfs && (_args_statfs == 2 || _args_statfs == 3) && \
-        ! _lib_statvfs && \
-        ! _lib_getmntinfo && \
-        ! _lib_getfsstat && \
-        ! _lib_getmnt && \
-        ! _lib_GetDiskFreeSpace && \
-        ! _lib_GetDiskFreeSpaceEx
+#if _lib_statfs && (_args_statfs == 2 || _args_statfs == 3) \
+        && ! _lib_statvfs \
+        && ! _lib_getmntinfo \
+        && ! _lib_getfsstat \
+        && ! _lib_getmnt \
+        && ! _lib_GetDiskFreeSpace \
+        && ! _lib_GetDiskFreeSpaceEx
 
 /*
  * di_getDiskInfo
@@ -366,8 +380,11 @@ di_getDiskInfo (diskInfo, diCount)
             } /* if we got the info */
             else
             {
+              diptr->printFlag = DI_PRNT_BAD;
+              if (errno != EACCES) {
                 fprintf (stderr, "statfs: %s ", diptr->name);
                 perror ("");
+              }
             }
         }
     } /* for each entry */
