@@ -1,5 +1,5 @@
 /*
- * $Id: dimntopt.h,v 1.10 2011-09-29 11:52:36-07 bll Exp $
+ * $Id: dimntopt.h,v 1.11 2013-01-18 08:32:56-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/dimntopt.h,v $
  * Copyright 2011 Brad Lanam, Walnut Creek, CA
  */
@@ -9,13 +9,13 @@
 
 #include "config.h"
 
-#if _hdr_mntent && \
-  ! defined (_DI_INC_MNTENT)        /* Linux, kFreeBSD, HP-UX */
+#if _hdr_mntent \
+  && ! defined (_DI_INC_MNTENT)        /* Linux, kFreeBSD, HP-UX */
 # define _DI_INC_MNTENT 1
 # include <mntent.h>                /* MNTOPT_... */
 #endif
-#if _sys_mount && \
-  ! defined (_DI_INC_SYS_MOUNT)     /* FreeBSD, OpenBSD, NetBSD, HP-UX */
+#if _sys_mount \
+  && ! defined (_DI_INC_SYS_MOUNT)     /* FreeBSD, OpenBSD, NetBSD, HP-UX */
 # define _DI_INC_SYS_MOUNT 1
 # include <sys/mount.h>             /* MNT_...; M_... (hp-ux) */
 #endif
