@@ -1,23 +1,25 @@
 /*
- * $Id: getoptn.c,v 1.7 2011-10-06 12:28:49-07 bll Exp $
+ * $Id: getoptn.c,v 1.12 2013-01-19 16:52:02-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/getoptn.c,v $
- * Copyright 2011 Brad Lanam, Walnut Creek, CA
+ * Copyright 2011-2013 Brad Lanam, Walnut Creek, CA
  */
 
 /*
  * A new version of getopt()
  *      Boolean short flags: -a -b  (a, b)
- *      Boolean short flags: -ab    (a, b)
- * or   Boolean long name:   -ab    (ab)
  *      With values:         -c 123 -d=abcdef -ef
  *                              (-c = 123, -d = abcdef, -e = f)
- *      short flags:         -version  (-v = ersion)
- * or   long flags:          -version  (-version)
  *      Long options:        --a --b --c 123 --d=abcdef
+ * LEGACY:
+ *      Boolean short flags: -ab    (a, b)
+ *      short flags:         -version  (-v = ersion)
+ * MODERN:
+ *      Boolean long name:   -ab    (ab)
+ *      long flags:          -version  (-version)
  *
  */
 
-#if TEST_GETOPTN
+#if defined(TEST_GETOPTN)
 # include "gconfig.h"
 #else
 # include "config.h"
@@ -36,7 +38,9 @@
 #if _hdr_strings
 # include <strings.h>
 #endif
-#if _sys_types
+#if _sys_types \
+    && ! defined (_DI_INC_SYS_TYPES_H) /* xenix */
+# define _DI_INC_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 
@@ -204,6 +208,7 @@ process_opt (info, opt, optinfo)
 {
   const char    *ptr;
 
+  ptr = (char *) NULL;
   if (opt->option_type == GETOPTN_INT ||
       opt->option_type == GETOPTN_LONG ||
       opt->option_type == GETOPTN_SIZET ||
@@ -372,14 +377,21 @@ getoptn (style, argc, argv, optcount, opts)
   return argc;
 }
 
-#if TEST_GETOPTN
+#if defined(TEST_GETOPTN)
 
 #if _hdr_math
 # include <math.h>
 #endif
 
 static void
-process_opts (const char *arg, char *valptr) {
+#if _proto_stdc
+process_opts (const char *arg, char *valptr)
+#else
+process_opts (arg, valptr)
+    const char  *arg;
+    char        *valptr;
+#endif
+{
   if (strcmp (arg, "-h") == 0) {
     double *v;
     v = (double *) valptr;
@@ -389,7 +401,15 @@ process_opts (const char *arg, char *valptr) {
 }
 
 static void
-process_opts_val (const char *arg, char *valptr, char *value) {
+#if _proto_stdc
+process_opts_val (const char *arg, char *valptr, char *value)
+#else
+process_opts_val (arg, valptr, value)
+    const char      *arg;
+    char            *valptr;
+    char            *value;
+#endif
+{
   if (strcmp (arg, "-g") == 0) {
     double *v;
     v = (double *) valptr;
@@ -399,7 +419,13 @@ process_opts_val (const char *arg, char *valptr, char *value) {
 }
 
 int
+#if _proto_stdc
 main (int argc, const char * const argv[])
+#else
+main (argc, argv)
+    int                 argc;
+    const char * const  argv[];
+#endif
 {
   char      tmp[40];
   char      s[40];
@@ -1243,6 +1269,21 @@ main (int argc, const char * const argv[])
     grc = 1;
   }
 
+  /* test 49 - test boolean initial value */
+  ++testno;
+  i = 0;
+  ac = 2;
+  sprintf (tmp, "test %d", testno);
+  av[0] = tmp;
+  av[1] = "-c";
+  av[2] = NULL;
+  optidx = getoptn (GETOPTN_LEGACY, ac, av,
+       sizeof (opts) / sizeof (getoptn_opt_t), opts);
+  if (i != 0) {
+    fprintf (stderr, "fail test %d\n", testno);
+    grc = 1;
+  }
+
   return grc;
 }
 
