@@ -1,19 +1,21 @@
 /*
- * $Id: getoptn.h,v 1.3 2011-10-05 18:28:41-07 bll Exp $
+ * $Id: getoptn.h,v 1.5 2013-01-18 08:33:42-08 bll Exp $
  * $Source: /home/bll/DI/di/C/RCS/getoptn.h,v $
- * Copyright 2011 Brad Lanam, Walnut Creek, CA
+ * Copyright 2011-2013 Brad Lanam, Walnut Creek, CA
  */
 
 #ifndef __INC_GETOPTN_H_
 #define __INC_GETOPTN_H_
 
-#if TEST_GETOPTN
+#if defined(TEST_GETOPTN)
 # include "gconfig.h"
 #else
 # include "config.h"
 #endif
 
-#if _sys_types
+#if _sys_types \
+    && ! defined (_DI_INC_SYS_TYPES_H) /* xenix */
+# define _DI_INC_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 
