@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: mkconfig.pl,v 1.102 2011-10-05 18:29:18-07 bll Exp $
+# $Id: mkconfig.pl,v 1.110 2012-11-10 18:57:50-08 bll Exp $
 #
 # Copyright 2006-2010 Brad Lanam Walnut Creek, CA USA
 #
@@ -12,12 +12,12 @@ require 5.005;
 
 my $CONFH;
 my $LOG = "mkconfig.log";
-my $TMP = "_tmp_mkconfig";
+my $_MKCONFIG_TMP = "_tmp_mkconfig";
 my $OPTIONFILE = "options.dat";
 my $VARSFILE = "mkc_none_c.vars";
 my $CACHEFILE = "mkconfig.cache";
 my $REQLIB = "mkconfig.reqlibs";
-my $MKC_DIR = "invalid";
+my $_MKCONFIG_DIR = "invalid";
 
 my $precc = <<'_HERE_';
 #if defined(__STDC__) || defined(__cplusplus) || defined(c_plusplus)
@@ -585,7 +585,12 @@ _HERE_
 sub
 check_command
 {
-    my ($name, $cmd, $r_clist, $r_config) = @_;
+    my ($name, $cmds, $r_clist, $r_config) = @_;
+
+    my @cmdlist = split (/ +/o, $cmds);
+    my $cmd = $cmdlist[0];
+    $name = "_command_${cmd}";
+    my $locnm = "_cmd_loc_${cmd}";
 
     printlabel $name, "command: $cmd";
     if (checkcache ($name, $r_clist, $r_config) == 0)
@@ -595,15 +600,49 @@ check_command
 
     setlist $r_clist, $name;
     $r_config->{$name} = 0;
-    foreach my $p (split /[;:]/o, $ENV{'PATH'})
+    foreach my $cmd (@cmdlist)
     {
+      foreach my $p (split /[;:]/o, $ENV{'PATH'})
+      {
         if (-x "$p/$cmd")
         {
-            $r_config->{$name} = "$p/$cmd";
-            last;
+          setlist $r_clist, $locnm;
+          $r_config->{$locnm} = "$p/$cmd";
+          $r_config->{$name} = 1;
+          last;
         }
+      }
     }
-    printyesno $name, $r_config->{$name};
+
+    printyesno_val $name, $r_config->{$name};
+}
+
+sub
+check_grep
+{
+    my ($name, $args, $r_clist, $r_config) = @_;
+
+    my @arglist = split (/ +/o, $args);
+    my $tag = $arglist[0];
+    my $pat= $arglist[1];
+    my $fn = $arglist[2];
+    $name = "_grep_${tag}";
+    my $locnm = "_grep_${tag}";
+
+    printlabel $name, "grep: $tag";
+    if (checkcache ($name, $r_clist, $r_config) == 0)
+    {
+        return;
+    }
+
+    setlist $r_clist, $name;
+    $r_config->{$name} = 0;
+    my $rc = system ("grep '${pat}' $fn > /dev/null 2>&1");
+    if ($rc == 0) {
+      $r_config->{$name} = 1;
+    }
+
+    printyesno_val $name, $r_config->{$name};
 }
 
 sub
@@ -716,7 +755,8 @@ check_if
         $nline .= $token . ' ';
       } else {
         print LOGFH "## value of $token: " . $r_config->{$token} . "\n";
-        $nline .= $r_config->{$token} ne '0' ? 1 : 0;
+        $nline .= $r_config->{$token} ne '0' &&
+              $r_config->{$token} ne '' ? 1 : 0;
         $nline .= ' ';
       }
     }
@@ -1026,14 +1066,11 @@ check_args
     my ($name, $funcnm, $r_a, $r_clist, $r_config) = @_;
 
     printlabel $name, "args: $funcnm";
-    if (checkcache_val ($name, $r_clist, $r_config) == 0)
-    {
-        return;
-    }
+    # no cache
 
     if ($ENV{'_MKCONFIG_USING_GCC'} == 'N' &&
         $ENV{'_MKCONFIG_SYSTYPE'} == 'HP-UX' ) {
-      my $tcc = `${CC} -v 2>&1`;
+      my $tcc = `$ENV{'CC'} -v 2>&1`;
       if ($tcc =~ /Bundled/o) {
         print " bundled cc; skipped";
         return;
@@ -1046,6 +1083,7 @@ check_args
 #define __attribute__(a)
 #define __nonnull__(a,b)
 #define __restrict
+#define __restrict__
 #define __THROW
 #define __const const
 ";
@@ -1060,7 +1098,7 @@ check_args
      $rc = system ($cmd);
      print LOGFH "##  args: $cmd $rc\n";
      if ($rc == 0) {
-       my $dcl = `${awkcmd} -f ${MKC_DIR}/mkcextdcl.awk ${name}.out ${funcnm}`;
+       my $dcl = `${awkcmd} -f ${_MKCONFIG_DIR}/util/mkcextdcl.awk ${name}.out ${funcnm}`;
        # $dcl may be multi-line...fix this now.
        $dcl =~ s/[ 	\n]/ /gos;
        $dcl =~ s/extern *//o;
@@ -1181,18 +1219,15 @@ check_memberxdr
     my ($name, $struct, $member, $r_clist, $r_config) = @_;
 
     printlabel $name, "member:xdr: $struct.$member";
-    if (checkcache ($name, $r_clist, $r_config) == 0)
-    {
-        return;
-    }
+    # no cache
 
     $r_config->{$name} = 0;
     my $rc = _chk_cpp ($name, "", $r_clist, $r_config,
         { 'incheaders' => 'all', });
     if ($rc == 0) {
       print LOGFH `pwd` . "\n";
-      print LOGFH "## ${awkcmd} -f ${MKC_DIR}/mkcextstruct.awk ${name}.out ${struct}\n";
-      my $st = `${awkcmd} -f ${MKC_DIR}/mkcextstruct.awk ${name}.out ${struct}`;
+      print LOGFH "## ${awkcmd} -f ${_MKCONFIG_DIR}/util/mkcextstruct.awk ${name}.out ${struct}\n";
+      my $st = `${awkcmd} -f ${_MKCONFIG_DIR}/util/mkcextstruct.awk ${name}.out ${struct}`;
       print LOGFH "##  xdr(A): $st\n";
       if ($st =~ m/${member}\s*;/s) {
         my $mtype = $st;
@@ -1286,12 +1321,17 @@ check_standard
 sub
 create_output
 {
-  my ($r_clist, $r_config, $include) = @_;
+  my ($r_clist, $r_config, $include, $configfile) = @_;
 
   if ($CONFH eq 'none') { return; }
 
+  my $dt=`date`;
   open (CCOFH, ">$CONFH");
   print CCOFH <<"_HERE_";
+/* Created on: ${dt}
+    From: ${configfile}
+    Using: mkconfig-${_MKCONFIG_VERSION} (perl) */
+
 #ifndef __INC_${CONFHTAGUC}_H
 #define __INC_${CONFHTAGUC}_H 1
 
@@ -1310,7 +1350,7 @@ _HERE_
       $tnm = $val;
       $tnm =~ s/^_setint_//;
       print CCOFH "#define $tnm " . $r_config->{$val} . "\n";
-    } elsif ($val =~ m#^(_setstr_|_opt_)#o) {
+    } elsif ($val =~ m#^(_setstr_|_opt_|_cmd_loc_)#o) {
       $tnm = $val;
       $tnm =~ s/^_setstr_//;
       $tnm =~ s/^_opt_//;
@@ -1403,6 +1443,8 @@ main_process
     my $include = '';
     my $tline = '';
     my $ifstmtcount = 0;
+    my $ifcurrlvl = 0;
+    my $doif = $ifcurrlvl;
     while (my $line = <DATAIN>)
     {
       chomp $line;
@@ -1445,22 +1487,33 @@ main_process
 
       if ($line =~ m#^\s*else#o)
       {
+        if ($ifcurrlvl == $doif) {
           $doproc = $doproc == 0 ? 1 : 0;
           $iflevels =~ s/.\d+\s$//;
           $iflevels .= "-$ifstmtcount ";
+        }
+      }
+      elsif ($line =~ m#^\s*if\s#o) {
+        if ($doproc == 0) {
+          $ifcurrlvl += 1;
+        }
       }
       elsif ($line =~ m#^\s*endif#o)
       {
-        if ($#doproclist >= 0) {
-          print LOGFH "## endif: doproclist: " . join (' ', @doproclist) . "\n";
-          $doproc = shift @doproclist;
-          print LOGFH "## endif: doproclist now : " . join (' ', @doproclist) . "\n";
-          print LOGFH "## endif: doproc: $doproc\n";
-          $iflevels =~ s/.\d+\s$//;
-        } else {
-          $doproc = 1;
-          $iflevels = '';
+        if ($ifcurrlvl == $doif) {
+          if ($#doproclist >= 0) {
+            print LOGFH "## endif: doproclist: " . join (' ', @doproclist) . "\n";
+            $doproc = shift @doproclist;
+            print LOGFH "## endif: doproclist now : " . join (' ', @doproclist) . "\n";
+            print LOGFH "## endif: doproc: $doproc\n";
+            $iflevels =~ s/.\d+\s$//;
+          } else {
+            $doproc = 1;
+            $iflevels = '';
+          }
+          $doif -= 1;
         }
+        $ifcurrlvl -= 1;
       }
 
       if ($doproc == 1) {
@@ -1468,7 +1521,7 @@ main_process
         {
             if ($inproc == 1) {
               savevars (\%clist);
-              create_output (\%clist, \%config, $include);
+              create_output (\%clist, \%config, $include, $configfile);
               $CONFH = 'none';
               $CONFHTAG = 'none';
               $CONFHTAGUC = 'NONE';
@@ -1577,9 +1630,12 @@ main_process
         }
         elsif ($line =~ m#^\s*command\s+(.*)#o)
         {
-            my $cmd = $1;
-            my $nm = "_command_" . $cmd;
-            check_command ($nm, $cmd, \%clist, \%config);
+            my $cmds = $1;
+            check_command ('', $cmds, \%clist, \%config);
+        }
+        elsif ($line =~ m#^\s*grep\s+(.*)#o)
+        {
+            check_grep ('', $1, \%clist, \%config);
         }
         elsif ($line =~ m#^\s*(if(not)?option)\s+([^\s]+)#o)
         {
@@ -1598,12 +1654,14 @@ main_process
         {
             my $iflabel = $1;
             my $ifline = $2;
+            ++$ifcurrlvl;
             ++$ifstmtcount;
             print LOGFH "## if: label: $iflabel count $ifstmtcount line: $ifline\n";
             my $rc = check_if ($iflabel, $ifstmtcount, $ifline, \%clist, \%config);
             $iflevels .= "+$ifstmtcount ";
             unshift @doproclist, $doproc;
             $doproc = $rc;
+            $doif = $ifcurrlvl;
             print LOGFH "## if: doproclist: " . join (' ', @doproclist) . "\n";
             print LOGFH "## if: doproc: $doproc\n";
         }
@@ -1763,7 +1821,7 @@ main_process
 
     savevars (\%clist);
     savecache (\%clist, \%config);
-    create_output (\%clist, \%config, $include);
+    create_output (\%clist, \%config, $include, $configfile);
 
     # This is here for os/2 and other systems w/no usable bourne shell.
     # it is not up to date, as it will output libraries that are not
@@ -1822,7 +1880,7 @@ if (! defined ($configfile) || ! -f $configfile)
   usage;
   exit 1;
 }
-if (-d $TMP && $TMP ne "_tmp_mkconfig")
+if (-d $_MKCONFIG_TMP && $_MKCONFIG_TMP ne "_tmp_mkconfig")
 {
   usage;
   exit 1;
@@ -1846,15 +1904,17 @@ chomp $currdir;
 if (! chdir $tpath) {
   die ("Unable to cd to $tpath. $!\n");
 }
-$MKC_DIR = `pwd`;
-chomp $MKC_DIR;
+$_MKCONFIG_VERSION=`cat $tpath/VERSION`;
+chomp $_MKCONFIG_VERSION;
+$_MKCONFIG_DIR = `pwd`;
+chomp $_MKCONFIG_DIR;
 if (! chdir $currdir) {
   die ("Unable to cd to $currdir. $!\n");
 }
 
-if (-d $TMP) { system ("rm -rf $TMP"); }
-mkdir $TMP, 0777;
-chdir $TMP;
+if (-d $_MKCONFIG_TMP) { system ("rm -rf $_MKCONFIG_TMP"); }
+mkdir $_MKCONFIG_TMP, 0777;
+chdir $_MKCONFIG_TMP;
 
 if ($clearcache)
 {
@@ -1879,6 +1939,6 @@ close LOGFH;
 
 chdir "..";
 if ($ENV{'MKC_KEEP_TMP'} eq "") {
-  if (-d $TMP) { system ("rm -rf $TMP"); }
+  if (-d $_MKCONFIG_TMP) { system ("rm -rf $_MKCONFIG_TMP"); }
 }
 exit 0;
