@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: mkconfig.sh,v 1.92 2011-10-05 16:27:26-07 bll Exp $
+# $Id: mkconfig.sh,v 1.105 2012-11-10 18:57:45-08 bll Exp $
 #
 # Copyright 2009-2010 Brad Lanam Walnut Creek, CA USA
 #
@@ -17,17 +17,17 @@
 
 set -f  # set this globally.
 
+unset CDPATH
 # this is a workaround for ksh93 on solaris
-if [ "$1" = "-d" ]; then
+if [ "$1" = -d ]; then
   cd $2
   shift
   shift
 fi
-unset CDPATH
-mypath=`echo $0 | sed -e 's,/[^/]*$,,'`
+mypath=`echo $0 | sed -e 's,/[^/]*$,,' -e 's,^\.,./.,'`
 _MKCONFIG_DIR=`(cd $mypath;pwd)`
 export _MKCONFIG_DIR
-. ${_MKCONFIG_DIR}/shellfuncs.sh
+. ${_MKCONFIG_DIR}/bin/shellfuncs.sh
 
 doshelltest $0 $@
 setechovars
@@ -38,6 +38,7 @@ CACHEFILE="mkconfig.cache"
 OPTIONFILE="options.dat"
 _MKCONFIG_PREFIX=mkc    # need a default in case no units loaded
 optionsloaded=F
+allchglist=""
 
 INC="mkcinclude.txt"                   # temporary
 
@@ -71,10 +72,11 @@ setvar () {
     svname=$2
 
     if [ $varsfileopen = F ]; then
-      for v in `set | grep "^mkv_" | sed 's/=.*$//'`; do
+      for v in `set | grep "^mkv_" | sed -e 's/=.*$//'`; do
         unset $v
       done
       varsfileopen=T
+      >$VARSFILE
       exec 8>>$VARSFILE
     fi
 
@@ -83,9 +85,7 @@ setvar () {
     rc=$?
     # if already in the list of vars, don't add it to the file again.
     if [ $rc -ne 0 ]; then
-      if [ $rc -ne 0 ]; then
-        echo ${svname} >&8
-      fi
+      echo ${svname} >&8
     fi
 
     cmd="mkv_${prefix}_${svname}=T"
@@ -229,16 +229,52 @@ _loadoptions () {
 
 check_command () {
     name=$1
-    ccmd=$2
+    shift
+    ccmd=$1
+
+    locnm=_cmd_loc_${ccmd}
 
     printlabel $name "command: ${ccmd}"
     checkcache ${_MKCONFIG_PREFIX} $name
     if [ $rc -eq 0 ]; then return; fi
 
-    locatecmd trc $ccmd
-    if [ "$trc" = "" ]; then trc=0; fi
-    printyesno $name $trc
+    trc=0
+    val=""
+    while test $# -gt 0; do
+      ccmd=$1
+      shift
+      locatecmd tval $ccmd
+      if [ "$tval" != "" ]; then
+        val=$tval
+        trc=1
+      fi
+    done
+
+    printyesno_val $name $val
     setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
+    if [ $trc -eq 1 ]; then
+      setdata ${_MKCONFIG_PREFIX} ${locnm} ${val}
+    fi
+}
+
+check_grep () {
+  name=$1; shift
+  tag=$1; shift
+  pat=$1; shift
+  fn=$1; shift
+
+  locnm=_grep_${name}
+
+  printlabel $name "grep: ${tag}"
+  checkcache ${_MKCONFIG_PREFIX} $name
+  if [ $rc -eq 0 ]; then return; fi
+
+  grep -l ${pat} ${fn} > /dev/null 2>&1
+  rc=$?
+  if [ $rc -eq 0 ]; then trc=1; else trc=0; fi
+
+  printyesno $name $trc
+  setdata ${_MKCONFIG_PREFIX} ${name} ${trc}
 }
 
 check_ifoption () {
@@ -253,13 +289,13 @@ check_ifoption () {
     trc=F  # if option is not set, it's false
 
     found=F
-    if [ "$optionsloaded" = T ]; then
+    if [ $optionsloaded = T ]; then
       eval tval=\$_mkc_opt_${oopt}
       if [ "$tval" != "" ]; then
         found=T
         trc=$tval
         tolower trc
-        echo "  found: $oopt $trc" >&9
+        echo "  found option: $oopt $trc" >&9
         if [ "$trc" = t ]; then trc=T; fi
         if [ "$trc" = enable ]; then trc=T; fi
         if [ "$trc" = f ]; then trc=F; fi
@@ -272,10 +308,10 @@ check_ifoption () {
     if [ "$trc" = T ]; then trc=1; fi
     if [ "$trc" = F ]; then trc=0; fi
 
-    if [ $type = "ifnotoption" ]; then
+    if [ $type = ifnotoption ]; then
       if [ $trc -eq 0 ]; then trc=1; else trc=0; fi
     fi
-    if [ "$optionsloaded" = F ]; then
+    if [ $optionsloaded = F ]; then
       trc=0
       printyesno_actual $name "no options file"
     elif [ "$found" = F ]; then
@@ -352,7 +388,7 @@ check_if () {
             ;;
           *)
             getdata tvar ${_MKCONFIG_PREFIX} $token
-            if [ "$tvar" != 0 ]; then tvar=1; fi
+            if [ "$tvar" != 0 -a "$tvar" != "" ]; then tvar=1; else tvar=0; fi
             tvar="( $tvar = 1 )"
             doappend nline " $tvar"
           ;;
@@ -388,7 +424,7 @@ check_set () {
   dosubst tnm '_setint_' '' '_setstr' ''
 
   printlabel $name "${type}: ${tnm}"
-  if [ "$type" = "set" ]; then
+  if [ "$type" = set ]; then
     getdata tval ${prefix} ${nm}
     if [ "$tval" != "" ]; then
       printyesno $nm "${sval}"
@@ -396,7 +432,7 @@ check_set () {
     else
       printyesno_actual $nm "no such variable"
     fi
-  elif [ "$type" = "setint" ]; then
+  elif [ "$type" = setint ]; then
     printyesno_actual $nm "${sval}"
     setdata ${_MKCONFIG_PREFIX} ${nm} "${sval}"
   else
@@ -405,6 +441,23 @@ check_set () {
   fi
 }
 
+_read_option () {
+  onm=$1
+  def=$2
+
+  _loadoptions
+
+  oval=$def
+  if [ $optionsloaded = T ]; then
+    eval tval=\$_mkc_opt_${onm}
+    if [ "$tval" != "" ]; then
+      found=T
+      echo "  found option: $onm $tval" >&9
+      oval="$tval"
+    fi
+  fi
+}
+
 check_option () {
   nm=$1
   onm=$2
@@ -412,19 +465,10 @@ check_option () {
 
   name=$nm
 
-  _loadoptions
-
-  oval=$def
   printlabel $name "option: ${onm}"
 
-  if [ "$optionsloaded" = T ]; then
-    eval tval=\$_mkc_opt_${onm}
-    if [ "$tval" != "" ]; then
-      found=T
-      echo "  found: $onm $tval" >&9
-      oval="$tval"
-    fi
-  fi
+  _read_option $onm "$def"
+
   printyesno_actual $nm "$oval"
   setdata ${_MKCONFIG_PREFIX} ${nm} "${oval}"
 }
@@ -441,6 +485,16 @@ check_exit () {
   _exitmkconfig 5
 }
 
+check_substitute () {
+  nm=$1
+  sub1=$2
+  sub2=$3
+
+  printlabel $nm "substitute: ${sub1} ${sub2}"
+  doappend allchglist " -e 's~${sub1}~${sub2}~g'"
+  printyesno $nm 1
+}
+
 _doloadunit () {
   lu=$1
   dep=$2
@@ -448,10 +502,10 @@ _doloadunit () {
    slu=${lu}
    tag=" (dependency)"
   fi
-  if [ -f ${_MKCONFIG_DIR}/mkconfig.units/${lu}.sh ]; then
+  if [ -f ${_MKCONFIG_DIR}/units/${lu}.sh ]; then
     echo "load-unit: ${lu} ${tag}" >&1
     echo "   found ${lu} ${tag}" >&9
-    . ${_MKCONFIG_DIR}/mkconfig.units/${lu}.sh
+    . ${_MKCONFIG_DIR}/units/${lu}.sh
     tlu=$lu
     dosubst tlu '-' '_'
     eval "_MKCONFIG_UNIT_${tlu}=Y"
@@ -480,10 +534,13 @@ require_unit () {
 
 _create_output () {
 
-  if [ ${CONFH} != "none" ]; then
+  if [ ${CONFH} != none ]; then
+    confdir=`echo ${CONFH} | sed -e 's,/[^/]*$,,'`
+    test -d $confdir || mkdir -p $confdir
+
     > ${CONFH}
     exec 8>>${CONFH}
-    preconfigfile ${CONFH} >&8
+    preconfigfile ${CONFH} ${configfile} >&8
 
     if [ -f $VARSFILE ]; then
       exec 6<&0 < $VARSFILE
@@ -498,8 +555,10 @@ _create_output () {
     cat $INC >&8
     postconfigfile ${CONFH} >&8
     exec 8>&-
-
-    output_other ${CONFH}
+    if [ "$allchglist" != "" ]; then
+      cmd="sed ${allchglist} ${CONFH} > ${CONFH}.tmp;mv ${CONFH}.tmp ${CONFH}"
+      eval $cmd
+    fi
   fi
 }
 
@@ -522,6 +581,8 @@ main_process () {
   ifstmtcount=0
   ifleveldisp=""
   iflevels=""
+  ifcurrlvl=0
+  doif=$ifcurrlvl
   initifs
   > $INC
   case ${configfile} in
@@ -544,65 +605,92 @@ main_process () {
     VARSFILE="../mkc_none_${_MKCONFIG_PREFIX}.vars"
   fi
 
+  # ksh93 93u 'read' changed.  Need the raw read for 'include'.
+  # Unfortunately, this affects other shells.
+  # shellfuncs tests for the necessity.
+  rawarg=
   # save stdin in fd 7; open stdin
   exec 7<&0 < ${configfile}
-  while read tdatline; do
+  while read ${rawarg} tdatline; do
     resetifs
     domath linenumber "$linenumber + 1"
+    echo "#### ${linenumber}: ${tdatline}" >&9
 
     if [ $ininclude -eq 1 ]; then
-        if [ "${tdatline}" = "endinclude" ]; then
-          echo "#### ${linenumber}: ${tdatline}" >&9
-          ininclude=0
-          resetifs
-        else
-          echo "${tdatline}" >> $INC
+      if [ "${tdatline}" = endinclude ]; then
+        ininclude=0
+        rawarg=
+        resetifs
+      else
+        if [ $shreqreadraw -eq 1 ]; then
+          # have to do our own backslash processing.
+          # backquotes suck.
+          tdatline=`echo "${tdatline}" |
+              sed -e 's/\\\\\\([^\\\\]\\)/\\1/g' -e 's/\\\\\\\\/\\\\/g'`
         fi
+        echo "${tdatline}" >> $INC
+      fi
     else
-        case ${tdatline} in
-            "")
-                continue
-                ;;
-            \#*)
-                continue
-                ;;
-            *)
-                echo "#### ${linenumber}: ${tdatline}" >&9
-                ;;
-        esac
+      case ${tdatline} in
+        "")
+          continue
+          ;;
+        \#*)
+          continue
+          ;;
+        *)
+          echo "#### ${linenumber}: ${tdatline}" >&9
+          ;;
+      esac
     fi
 
     if [ $ininclude -eq 0 ]; then
       case ${tdatline} in
         "else")
-          if [ $doproc -eq 0 ]; then doproc=1; else doproc=0; fi
-          set -- $iflevels
-          shift
-          iflevels=$@
-          iflevels="-$ifstmtcount $iflevels"
-          _setifleveldisp
-          echo "## else iflevels: $iflevels" >&9
-          ;;
-        "endif")
-          set $doproclist
-          c=$#
-          if [ $c -gt 0 ]; then
-            echo "## doproclist: $doproclist" >&9
-            doproc=$1
-            shift
-            doproclist=$@
-            echo "## doproc: $doproc doproclist: $doproclist" >&9
+          if [ $ifcurrlvl -eq $doif ]; then
+            if [ $doproc -eq 0 ]; then doproc=1; else doproc=0; fi
             set -- $iflevels
             shift
             iflevels=$@
+            iflevels="-$ifstmtcount $iflevels"
             _setifleveldisp
-            echo "## endif iflevels: $iflevels" >&9
+            echo "## else iflevels: $iflevels" >&9
           else
-            doproc=1
-            ifleveldisp=""
-            iflevels=""
+            echo "## else: ifcurrlvl: $ifcurrlvl doif: $doif" >&9
           fi
           ;;
+        "if "*)
+          if [ $doproc -eq 0 ]; then
+            domath ifcurrlvl "$ifcurrlvl + 1"
+            echo "## if: ifcurrlvl: $ifcurrlvl doif: $doif" >&9
+          fi
+          ;;
+        "endif")
+          echo "## endifA: ifcurrlvl: $ifcurrlvl doif: $doif" >&9
+          if [ $ifcurrlvl -eq $doif ]; then
+            set $doproclist
+            c=$#
+            if [ $c -gt 0 ]; then
+              echo "## doproclist: $doproclist" >&9
+              doproc=$1
+              shift
+              doproclist=$@
+              echo "## doproc: $doproc doproclist: $doproclist" >&9
+              set -- $iflevels
+              shift
+              iflevels=$@
+              _setifleveldisp
+              echo "## endif iflevels: $iflevels" >&9
+            else
+              doproc=1
+              ifleveldisp=""
+              iflevels=""
+            fi
+            domath doif "$doif - 1"
+          fi
+          domath ifcurrlvl "$ifcurrlvl - 1"
+          echo "## endifB: ifcurrlvl: $ifcurrlvl doif: $doif" >&9
+          ;;
       esac
 
       if [ $doproc -eq 1 ]; then
@@ -611,8 +699,17 @@ main_process () {
             _chkconfigfname
             set $tdatline
             cmd=$2
+            shift
             nm="_command_${cmd}"
-            check_command ${nm} ${cmd}
+            check_command ${nm} $@
+            ;;
+          grep*)
+            _chkconfigfname
+            set $tdatline
+            tag=$2
+            shift
+            nm="_grep_${tag}"
+            check_grep ${nm} $@
             ;;
           "echo"*)
             _chkconfigfname
@@ -624,6 +721,9 @@ main_process () {
           "exit")
             check_exit
             ;;
+          substitute)
+            check_substitute $@
+            ;;
           endinclude)
             ;;
           ifoption*|ifnotoption*)
@@ -649,6 +749,8 @@ main_process () {
             label=$1
             shift
             ifline=$@
+            domath ifcurrlvl "$ifcurrlvl + 1"
+            echo "## if: ifcurrlvl: $ifcurrlvl" >&9
             domath ifstmtcount "$ifstmtcount + 1"
             check_if $label $ifstmtcount "$ifline"
             rc=$?
@@ -657,6 +759,7 @@ main_process () {
             echo "## if iflevels: $iflevels" >&9
             doproclist="$doproc $doproclist"
             doproc=$rc
+            doif=$ifcurrlvl
             echo "## doproc: $doproc doproclist: $doproclist" >&9
             ;;
           "else")
@@ -666,6 +769,9 @@ main_process () {
           include)
             _chkconfigfname
             ininclude=1
+            if [ $shreqreadraw -eq 1 ]; then
+              rawarg=-r
+            fi
             ;;
           loadunit*)
             set $tdatline
@@ -705,9 +811,11 @@ main_process () {
             check_option ${nm} $optnm "${tval}"
             ;;
           output*)
+            newout=F
             if [ $varsfileopen = T ]; then
               exec 8>&-
               varsfileopen=F
+              newout=T
             fi
             if [ $inproc -eq 1 ]; then
               _create_output
@@ -715,6 +823,10 @@ main_process () {
               CONFHTAG=none
               CONFHTAGUC=NONE
             fi
+            if [ $newout = T ]; then
+              new_output_file
+              > $INC  # restart include
+            fi
             set $tdatline
             type=$1
             file=$2
@@ -750,7 +862,7 @@ main_process () {
             set $tdatline
             type=$1
             nm=$2
-            if [ "$type" = "setint" -o "$type" = "setstr" ]; then
+            if [ "$type" = setint -o "$type" = setstr ]; then
               nm="_${type}_$2"
             fi
             shift; shift
@@ -836,7 +948,7 @@ if [ $# -ne 1 ] || [ ! -f $configfile  ]; then
   usage
   exit 1
 fi
-if [ -d $_MKCONFIG_TMP -a $_MKCONFIG_TMP != "_tmp_mkconfig" ]; then
+if [ -d $_MKCONFIG_TMP -a $_MKCONFIG_TMP != _tmp_mkconfig ]; then
   echo "$_MKCONFIG_TMP must not exist."
   usage
   exit 1
