@@ -1,6 +1,6 @@
 #!/bin/sh
 
-. $_MKCONFIG_DIR/testfuncs.sh
+. $_MKCONFIG_DIR/bin/testfuncs.sh
 
 maindodisplay $1 'w/single lib'
 maindoquery $1 $_MKC_SH_PL
@@ -36,18 +36,22 @@ ${_MKCONFIG_SHELL} ${_MKCONFIG_DIR}/mkconfig.sh -d `pwd` \
     -C $_MKCONFIG_RUNTESTDIR/c.env.dat
 . ./c.env
 
-${CC} -c ${CFLAGS} ${CPPFLAGS} tst1lib.c
+${_MKCONFIG_SHELL} ${_MKCONFIG_DIR}/mkc.sh -d `pwd` -comp -e -o tst1lib${OBJ_EXT} tst1lib.c
 if [ $? -ne 0 ]; then
   echo "compile tst1lib.c failed"
   exit 1
 fi
-ar cq libtst1lib.a tst1lib${OBJ_EXT}
+${_MKCONFIG_SHELL} ${_MKCONFIG_DIR}/mkc.sh -d `pwd` \
+    -staticlib libtst1lib tst1lib${OBJ_EXT}
 
 dorunmkc reqlibs out.h
 
 chkouthcompile
-sed -e '/^#define _key_/d' -e '/^#define _proto_/d' \
-    -e '/^#define _param_/d' out.h > out.h.n
+sed -e '/^#define _key_/d' \
+    -e '/^#define _proto_/d' \
+    -e '/^#define _param_/d' \
+    -e '/Created on: /,/Using: mkc/ d' \
+    out.h > out.h.n
 chkdiff c-singlelib.ctmp out.h.n
 chkdiff ${_MKCONFIG_RUNTESTDIR}/c-singlelib.reqlibs mkconfig.reqlibs
 
