@@ -1,6 +1,6 @@
 #!/bin/sh
 
-. $_MKCONFIG_DIR/testfuncs.sh
+. $_MKCONFIG_DIR/bin/testfuncs.sh
 
 maindodisplay $1 'c library'
 maindoquery $1 $_MKC_SH
@@ -16,9 +16,11 @@ ${_MKCONFIG_SHELL} ${_MKCONFIG_DIR}/mkconfig.sh -d `pwd` \
 dorunmkc
 
 grep -v SYSTYPE out.d |
+    grep -v '^//' |
     grep -v 'D_VERSION' |
     grep -v '_d_tango_lib' |
     grep -v '_csiz_' |
+    grep -v 'alias [a-z]* C_NATIVE_[a-z_]*;' |
     grep -v 'alias char.. string;' |
     grep -v '_type_string' |
     grep -v '^import std.*string' |
