@@ -1,6 +1,6 @@
 #!/bin/sh
 
-. $_MKCONFIG_DIR/testfuncs.sh
+. $_MKCONFIG_DIR/bin/testfuncs.sh
 
 maindodisplay $1 'c-struct extraction'
 maindoquery $1 $_MKC_SH
@@ -32,6 +32,7 @@ struct sa
   int   i;
   signed int   sgi;
   unsigned int   ui;
+  unsigned ui2;
   short s;
   signed short sgs;
   short int si;
@@ -167,7 +168,7 @@ struct sw
   double  c;
   struct sww {
     double d;
-  };
+  } sw2;
 };
 
 /* named struct */
@@ -208,6 +209,165 @@ struct saa
   _saaa;
 };
 
+/* typedef named struct - from freebsd rpc/xdr.h (XDR) */
+typedef struct sbb {
+  int     op;
+  const struct __rpc_xdr {
+    int (*x_getlong)(struct __rpc_xdr *, long *);
+    int (*x_putlong)(struct __rpc_xdr *, const long *);
+    void (*x_destroy)(struct __rpc_xdr *);
+  } *x_ops;
+  void *x_private;
+  char *x_base;
+  int   x_handy;
+} tXDR;
+
+/* typedef named struct - from freebsd rpc/xdr.h (XDR) */
+typedef struct _tscc {
+  int     op;
+  const struct tscc {
+    int (*x_getlong)(struct tscc *, long *);
+    int *(*x_inline)(struct tscc *, int);
+    void (*x_destroy)(struct tscc *);
+  } *x_ops;
+  void *x_private;
+  char *x_base;
+  int   x_handy;
+} scc;
+
+/* modified from rpc/clnt.h: CLIENT */
+struct sdd {
+  long      *cl_auth;
+  struct clnt_ops {
+    enum xdr_op (*cl_call) (struct sdd *, long, int, char *, int, char *, int);
+    void (*cl_abort) (void);
+    void (*cl_geterr) (struct sdd *, int *);
+    int (*cl_freeres) (struct sdd *, long, char *);
+  } *cl_ops;
+  char *cl_private;
+};
+
+/* uses struct name in functions */
+typedef struct see {
+  int     op;
+  struct see *next;
+  struct seestuff {
+    int (*x_getlong)(struct see *, long *);
+    int (*x_putlong)(struct see *, const long *);
+    void (*x_destroy)(struct see *);
+  } *see_stuff;
+  void *morestuff;
+} SEE;
+
+/* uses struct name in functions */
+typedef struct __sff {
+  int     op;
+  struct __sff *next;
+  struct sffstuff {
+    int (*x_getlong)(struct __sff *, long *);
+    int (*x_putlong)(struct __sff *, const long *);
+    void (*x_destroy)(struct __sff *);
+  } *sff_stuff;
+  void *moreffstuff;
+} SFF;
+
+/* typedef of struct; same name */
+typedef struct sgg
+{
+  double  c;
+  struct sgg1 {
+    double d;
+  } _sgg1;
+} sgg;
+
+/* typedef of struct; diff name; use struct name */
+typedef struct shh
+{
+  double  c;
+  struct shh1 {
+    double d;
+  } _shh1;
+} shh_t;
+
+/* typedef of struct; diff name; use typedef name */
+typedef struct sii_s
+{
+  double  c;
+  struct sii1 {
+    double d;
+  } _sii1;
+} sii;
+
+/* non-typedef same name */
+struct sjj
+{
+  double  c;
+  struct sjj1 {
+    double d;
+  } _sjj1;
+} sjj;
+
+struct skk { struct SKKB { int skka; } *skkb; };
+
+typedef struct sllstuff_ *sllstuff;
+struct sll {
+  int sll_a;
+  int sll_b;
+};
+
+struct smm {
+  int smm_b;
+  int *(*smm_a) (int *tablePtr,
+	    char *key);
+};
+
+typedef struct snn {
+  int snn_a;
+  int (*private15)(
+    struct snn*
+  );
+  int snn_b;
+} snn;
+
+typedef struct
+
+{
+ int *ext_data;
+ int *private1;
+ int fd;
+ int private19;
+ char *xdefaults;
+}
+
+*_soo;
+
+struct sppX {
+ long sppXa;
+ long sppXb;
+};
+
+// bitfields with sizeof
+struct spp {
+ int sppa;
+ int sppb;
+ int sppc;
+ struct sppX sppd;
+ unsigned int :(8 / 2) * (16 - (int)sizeof(struct sppX));
+ unsigned int :(8 / 2) * (16 - (int)sizeof(struct sppX));
+};
+
+struct sqq {
+  int sqq1;
+  int sqqa : 1;
+  int sqqb : 3;
+  int sqqc : 4;
+  int sqq2;
+  int sqqd : 4;
+  int sqqe : 6;
+  int sqqf : 6;
+  int sqq3;
+};
+
 union ua
 {
   long double ld;
@@ -333,12 +493,10 @@ union us {
  } us_named ;
 } us_t;
 
-/* doesnt work...(extraction fails)
 typedef union
 {
   double  c;
 } ut;
-*/
 
 typedef union uu
 {
@@ -361,15 +519,20 @@ ${_MKCONFIG_SHELL} ${_MKCONFIG_DIR}/mkconfig.sh -d `pwd` \
 dorunmkc
 
 for x in sa sb sc sd se sf sg sh si sj sk sl sm sn so sq sr \
-    ss st su sv sw sx sy sz saa ; do
+    ss st su sv sw sx sy sz saa sbb scc sdd see SFF sgg \
+    shh sii sjj sll smm snn _soo sppX spp; do
   chkoutd "^enum (: )?bool ({ )?_cstruct_${x} = true( })?;$"
 done
+for x in sc_t sd_t sk_t sl_t st_t su_t sv tXDR scc SEE SFF sgg shh_t \
+    sii snn _soo uc_t ud_t uk_t ul_t ut uu; do
+  chkoutd "^enum (: )?bool ({ )?_ctypedef_${x} = true( })?;$"
+done
 
 for x in sp; do
   chkoutd "^enum (: )?bool ({ )?_cstruct_${x} = false( })?;$"
 done
 
-for x in ua ub uc ud ue uf ug uh ui uj uk ul um un uo uq ur us uu; do
+for x in ua ub uc ud ue uf ug uh ui uj uk ul um un uo uq ur us ut uu; do
   chkoutd "^enum (: )?bool ({ )?_cunion_${x} = true( })?;$"
 done
 
